Get Metadata for a File Stored on a Provider
Arguments
- .provider
A provider function call.
- .file_id
The file ID string to look up, or a
tidyllm_fileobject returned byupload_file().- ...
Additional provider-specific arguments.
Get Metadata for a File Stored on a Provider
A provider function call.
The file ID string to look up, or a tidyllm_file object returned by upload_file().
Additional provider-specific arguments.