The openai() function acts as an interface for interacting with the OpenAI API through main tidyllm verbs such as chat(), embed(), and send_batch(). Chat uses the Responses API (POST /v1/responses); embeddings and batch operations use the Chat Completions / Embeddings endpoints unchanged.
Source: R/api_openai.R
openai.RdThe openai() function acts as an interface for interacting with the OpenAI API
through main tidyllm verbs such as chat(), embed(), and send_batch().
Chat uses the Responses API (POST /v1/responses); embeddings and batch operations
use the Chat Completions / Embeddings endpoints unchanged.