Check the Status of a Perplexity Deep Research Job
Source:R/api_perplexity.R
perplexity_check_research.RdCheck the Status of a Perplexity Deep Research Job
Usage
perplexity_check_research(
.job,
.api_key = Sys.getenv("PERPLEXITY_API_KEY"),
.max_tries = 3
)