Learn R Programming

tidyllm (version 0.5.1)

audio_file: Create an Audio Object

Description

Stores a reference to a local audio file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.

Usage

audio_file(.path)

Value

A tidyllm_audio object.

Arguments

.path

The path to the audio file on disk.