powered by
Stores a reference to a local audio file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.
audio_file(.path)
A tidyllm_audio object.
tidyllm_audio
The path to the audio file on disk.