file_info: Get Metadata for a File Stored on a Provider
Description
Get Metadata for a File Stored on a Provider
Usage
file_info(.provider, .file_id, ...)
Value
A single-row tibble of file metadata.
Arguments
- .provider
A provider function call.
- .file_id
The file ID string to look up, or a tidyllm_file object returned by upload_file().
- ...
Additional provider-specific arguments.