This function reads an image file from disk, encodes it in base64,
and returns a tidyllm_image object that can be used in multimodal
embedding requests or attached to messages via .media.
This function reads an image file from disk, encodes it in base64,
and returns a tidyllm_image object that can be used in multimodal
embedding requests or attached to messages via .media.