Learn R Programming

tidyllm (version 0.5.1)

img: Create an Image Object

Description

This function reads an image file from disk, encodes it in base64, and returns a tidyllm_image object that can be used in multimodal embedding requests or attached to messages via .media.

Usage

img(.path)

Value

A tidyllm_image object.

Arguments

.path

The path to the image file on disk.