Learn R Programming

tidyllm (version 0.6.0)

openai: The openai() function acts as an interface for interacting with the OpenAI API through main tidyllm verbs such as chat(), embed(), and send_batch(). Chat uses the Responses API (POST /v1/responses); embeddings and batch operations use the Chat Completions / Embeddings endpoints unchanged.

Description

The openai() function acts as an interface for interacting with the OpenAI API through main tidyllm verbs such as chat(), embed(), and send_batch(). Chat uses the Responses API (POST /v1/responses); embeddings and batch operations use the Chat Completions / Embeddings endpoints unchanged.

Usage

openai(..., .called_from = NULL)

Value

Result of the requested action.

Arguments

...

Parameters passed to the appropriate OpenAI-specific function.

.called_from

Internal routing argument; do not set manually.