Stores a reference to a local video file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.
Stores a reference to a local video file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.