Learn R Programming

tidyllm (version 0.5.1)

video_file: Create a Video Object

Description

Stores a reference to a local video file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.

Usage

video_file(.path)

Value

A tidyllm_video object.

Arguments

.path

The path to the video file on disk.