powered by
Stores a reference to a local video file for use in multimodal messages. The file is not encoded until the message is formatted for a provider.
video_file(.path)
A tidyllm_video object.
tidyllm_video
The path to the video file on disk.